@@ -1,7 +1,7 @@
 Met.Checkbox1 <-
 function(title,question1,question2,answer1,answer2,answer3,answer4)
 {
-  Require("tcltk")
+  require(tcltk)
   tt <- tktoplevel()
   tkgrab.set(tt)
   tkwm.title(tt,title)
